@@ -1,17 +1,25 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from pypika.enums import Dialects
 from pypika.queries import QueryBuilder
 
 from p3orm.drivers.base import BaseDriver
-from p3orm.drivers.postgres import PostgresDriver
-from p3orm.drivers.sqlite import SqliteDriver
 from p3orm.exceptions import NotConnected
 from p3orm.utils import validate_sqlite_version
 
+if TYPE_CHECKING:
+    from p3orm.drivers.postgres import PostgresDriver
+    from p3orm.drivers.sqlite import SqliteDriver
+
 DRIVER: BaseDriver = None
 DIALECT: Dialects = None
 
 
 def postgres() -> PostgresDriver:
+    from p3orm.drivers.postgres import PostgresDriver
+
     global DRIVER, DIALECT
     if DRIVER:
         return DRIVER
@@ -21,6 +29,8 @@ def postgres() -> PostgresDriver:
 
 
 def sqlite() -> SqliteDriver:
+    from p3orm.drivers.sqlite import SqliteDriver
+
     global DRIVER, DIALECT
     if DRIVER:
         return DRIVER
